
function makeBlock()
    craft.shader.add(HeightShader2D)
    block = scene:entity()
    block.position = vec3(-3, 0, 0)
    block.model = craft.model.cube(vec3(2,2,2))
    block.material = craft.material("Height Shader 2D")
    block.material.inTexture = readImage(asset.builtin.Surfaces.Desert_Cliff_Height)
    block.material.ramp = createTerrainRamp()
end
    
HeightShader2D = {
    name = "Height Shader 2D",
    
    options = {
        USE_COLOR = { true },
    },
    
    
    properties = {
        inTexture = {"texture2D", nil},
        ramp = {"texture2D", nil},
        tiling = {"float", 1.0},
        time = {"float", 0.0},
    },
    
    pass = {
        base = "Surface",
        blendMode = "disabled",
        depthWrite = true,
        depthFunc = "lessEqual",
        renderQueue = "solid",
        colorMask = {"rgba"},
        cullFace = "back",
        
        vertex = [[
        uniform mat4 modelViewProjection;
        void vertex(inout Vertex v, out Input o) {
            o.uv = v.uv;
            o.color = v.color;
            gl_Position = modelViewProjection * vec4(v.position, 1.0);
        }
    ]],

surface = [[
uniform sampler2D inTexture;
uniform sampler2D ramp;
uniform float tiling;
uniform float time;
lowp vec4 col;
lowp vec4 rampCol;
void surface(in Input IN, inout SurfaceOutput o) {
    lowp vec4 col = texture(inTexture, IN.uv * tiling) * IN.color;
    lowp vec4 rampCol = texture(ramp, vec2(clamp(col.r, 0.01, 0.99), 0.5));
    o.diffuse = rampCol.rgb;
    o.emissive = 0.0;
    o.emission = vec3(0.0);
}

]]
}}