function makeSphere()
    craft.shader.add(HeightShaderCubetexture)    
    testPlanet = scene:entity()
    testPlanet.model = craft.model.icosphere(2, 4)
    testPlanet.material = craft.material("Height Shader Cubetexture")
    testPlanet.material.heightMap = cubeMapFromImage(readImage(asset.builtin.Surfaces.Desert_Cliff_Height))
    testPlanet.material.ramp = createTerrainRamp()
    testPlanet.material.tiling = 1.0
    testPlanet.material.time = 0.0
    testPlanet.position = vec3(0, 0, 0)
end
       
HeightShaderCubetexture = {
    name = "Height Shader Cubetexture",
    options = {},
    properties = {
        heightMap = {"cubeTexture", nil},  -- the cube texture with height data
        ramp      = {"texture2D", nil},      -- the ramp texture for mapping height to color
        tiling    = {"float", 1.0},
        time      = {"float", 0.0}
    },
    pass = {
        base = "Surface",
        blendMode = "disabled",
        depthWrite = true,
        depthFunc = "lessEqual",
        renderQueue = "solid",
        colorMask = {"rgba"},
        cullFace = "back",
        vertex = [[
        uniform mat4 modelViewProjection; 
        void vertex(inout Vertex v, out Input o) {
            o.uv = v.uv;
            o.color = v.color;
            // Transform the object-space normal into world space.
            // We use vec4(v.normal, 0.0) so that translation is ignored.
            vec3 worldNormal = normalize((modelMatrix * vec4(v.normal, 0.0)).xyz);
            // Pass world normal in the Input structure.
            o.normal = worldNormal;
            gl_Position = modelViewProjection * vec4(v.position, 1.0);
        }
    ]],
surface = [[
precision highp float;
uniform samplerCube heightMap;
uniform sampler2D ramp;
uniform float tiling;
uniform float time;
vec3 vNormal;  // not strictly needed if IN.normal is provided
// In the surface function, use IN.normal (which should now be world-space):
    void surface(in Input IN, inout SurfaceOutput o) {
        vec3 lookup = normalize(IN.normal);
        vec4 h = texture(heightMap, lookup);
        float heightVal = h.r;
        lowp vec4 rampCol = texture(ramp, vec2(clamp(heightVal, 0.0, 1.0), 0.5));
        o.diffuse = rampCol.rgb;
        o.emissive = 0.0;
        o.emission = vec3(0.0);
    }
]]
}
}